@@ -162,7 +162,13 @@ class ApplicationProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApplicationProps.__init__)
+            def stub(
+                *,
+                application_name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -248,7 +254,14 @@ class AttributeGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AttributeGroupProps.__init__)
+            def stub(
+                *,
+                attribute_group_name: builtins.str,
+                attributes: typing.Mapping[builtins.str, typing.Any],
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument attribute_group_name", value=attribute_group_name, expected_type=type_hints["attribute_group_name"])
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
@@ -353,7 +366,16 @@ class CfnApplication(
         :param tags: Key-value pairs you can use to associate with the application.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnApplication.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnApplicationProps(name=name, description=description, tags=tags)
@@ -367,7 +389,9 @@ class CfnApplication(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnApplication.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -380,7 +404,9 @@ class CfnApplication(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnApplication._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -436,7 +462,9 @@ class CfnApplication(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnApplication, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -452,7 +480,9 @@ class CfnApplication(
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnApplication, "description").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -496,7 +526,14 @@ class CfnApplicationProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnApplicationProps.__init__)
+            def stub(
+                *,
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
@@ -604,7 +641,17 @@ class CfnAttributeGroup(
         :param tags: Key-value pairs you can use to associate with the attribute group.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroup.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                attributes: typing.Any,
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnAttributeGroupProps(
@@ -620,7 +667,9 @@ class CfnAttributeGroup(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroup.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -633,7 +682,9 @@ class CfnAttributeGroup(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroup._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -687,7 +738,9 @@ class CfnAttributeGroup(
     @attributes.setter
     def attributes(self, value: typing.Any) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "attributes").fset)
+            def stub(value: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributes", value)
 
@@ -703,7 +756,9 @@ class CfnAttributeGroup(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -719,7 +774,9 @@ class CfnAttributeGroup(
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "description").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -766,7 +823,15 @@ class CfnAttributeGroupAssociation(
         :param attribute_group: The name or ID of the attribute group that holds the attributes to describe the application.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                application: builtins.str,
+                attribute_group: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnAttributeGroupAssociationProps(
@@ -782,7 +847,9 @@ class CfnAttributeGroupAssociation(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -795,7 +862,9 @@ class CfnAttributeGroupAssociation(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -847,7 +916,9 @@ class CfnAttributeGroupAssociation(
     @application.setter
     def application(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnAttributeGroupAssociation, "application").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
@@ -863,7 +934,9 @@ class CfnAttributeGroupAssociation(
     @attribute_group.setter
     def attribute_group(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnAttributeGroupAssociation, "attribute_group").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributeGroup", value)
 
@@ -900,7 +973,13 @@ class CfnAttributeGroupAssociationProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroupAssociationProps.__init__)
+            def stub(
+                *,
+                application: builtins.str,
+                attribute_group: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument application", value=application, expected_type=type_hints["application"])
             check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -989,7 +1068,15 @@ class CfnAttributeGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnAttributeGroupProps.__init__)
+            def stub(
+                *,
+                attributes: typing.Any,
+                name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
@@ -1098,7 +1185,16 @@ class CfnResourceAssociation(
         :param resource_type: The type of resource of which the application will be associated. Possible values: CFN_STACK.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnResourceAssociation.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                application: builtins.str,
+                resource: builtins.str,
+                resource_type: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnResourceAssociationProps(
@@ -1114,7 +1210,9 @@ class CfnResourceAssociation(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnResourceAssociation.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -1127,7 +1225,9 @@ class CfnResourceAssociation(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnResourceAssociation._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1179,7 +1279,9 @@ class CfnResourceAssociation(
     @application.setter
     def application(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "application").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
@@ -1195,7 +1297,9 @@ class CfnResourceAssociation(
     @resource.setter
     def resource(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "resource").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
@@ -1213,7 +1317,9 @@ class CfnResourceAssociation(
     @resource_type.setter
     def resource_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "resource_type").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceType", value)
 
@@ -1257,7 +1363,14 @@ class CfnResourceAssociationProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnResourceAssociationProps.__init__)
+            def stub(
+                *,
+                application: builtins.str,
+                resource: builtins.str,
+                resource_type: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument application", value=application, expected_type=type_hints["application"])
             check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
             check_type(argname="argument resource_type", value=resource_type, expected_type=type_hints["resource_type"])
@@ -1398,7 +1511,9 @@ class _IApplicationProxy(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IApplication.associate_attribute_group)
+            def stub(attribute_group: "IAttributeGroup") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         return typing.cast(None, jsii.invoke(self, "associateAttributeGroup", [attribute_group]))
 
@@ -1411,7 +1526,9 @@ class _IApplicationProxy(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IApplication.associate_stack)
+            def stub(stack: aws_cdk.core.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(None, jsii.invoke(self, "associateStack", [stack]))
 
@@ -1517,7 +1634,15 @@ class Application(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Application.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                application_name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApplicationProps(
@@ -1543,7 +1668,13 @@ class Application(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Application.from_application_arn)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                application_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument application_arn", value=application_arn, expected_type=type_hints["application_arn"])
@@ -1558,7 +1689,9 @@ class Application(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Application.associate_attribute_group)
+            def stub(attribute_group: IAttributeGroup) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         return typing.cast(None, jsii.invoke(self, "associateAttributeGroup", [attribute_group]))
 
@@ -1573,7 +1706,9 @@ class Application(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Application.associate_stack)
+            def stub(stack: aws_cdk.core.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(None, jsii.invoke(self, "associateStack", [stack]))
 
@@ -1586,7 +1721,9 @@ class Application(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Application._generate_unique_hash)
+            def stub(resource_address: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument resource_address", value=resource_address, expected_type=type_hints["resource_address"])
         return typing.cast(builtins.str, jsii.invoke(self, "generateUniqueHash", [resource_address]))
 
@@ -1657,7 +1794,16 @@ class AttributeGroup(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AttributeGroup.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                attribute_group_name: builtins.str,
+                attributes: typing.Mapping[builtins.str, typing.Any],
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AttributeGroupProps(
@@ -1685,7 +1831,13 @@ class AttributeGroup(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AttributeGroup.from_attribute_group_arn)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                attribute_group_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument attribute_group_arn", value=attribute_group_arn, expected_type=type_hints["attribute_group_arn"])
